@@ -51,14 +51,30 @@ def enter_and_leave_function(func: Callable) -> Callable:
         func_def_file = inspect.getsourcefile(func) or "unknown_file"
         func_def_file = func_def_file.split("/")[-1]
         func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
+        log.info(
+            f"[{func_def_file}: {func_def_line}]"
+            f"[{func.__name__}()]"
+            f"| args={args}, kwargs={kwargs}"
+        )
+
         try:
             result = func(*args, **kwargs)
             if isinstance(result, ExecResult):
-                if result.exit_status_code != 0:
-                    log.warning(
+                if result.exit_status_code == 0:
+                    log.info(
+                        f"[{func_def_file}: {func_def_line}]"
+                        f" finish run function {func.__name__}(), stdout is: {result.stdout} "
+                    )
+                else:
+                    log.error(
                         f"[{func_def_file}: {func_def_line}]"
                         f" failed to run function {func.__name__}(), stderr is: {result.stderr} "
                     )
+            else:
+                log.info(
+                    f"[{func_def_file}: {func_def_line}]"
+                    f" finish run function {func.__name__}(), return value is: {result} "
+                )
             return result
 
         except Exception as e:
